@@ -163,10 +163,14 @@ playSetFreezeGUI <- function(playState, frozen)
     with(playState$widgets, {
         topToolbar["sensitive"] <- !frozen
         leftToolbar["sensitive"] <- !frozen
-        bottomToolbar["sensitive"] <- !frozen
         rightToolbar["sensitive"] <- !frozen
-        pageScrollBox["sensitive"] <- !frozen
-        timeScrollBox["sensitive"] <- !frozen
+        ## leave bottom toolbar alone as this is where parameter
+        ## control tools go (otherwise long slider drags interrupted).
+        ## these tools check plot.ready before redrawing (threads...).
+        #bottomToolbar["sensitive"] <- !frozen
+        ## similarly, leave page and time scrollbars as sensitive.
+        #pageScrollBox["sensitive"] <- !frozen
+        #timeScrollBox["sensitive"] <- !frozen
                                         #callToolbar["sensitive"] <- !frozen
     })
     playState$win$getWindow()$setCursor(
@@ -872,14 +876,12 @@ playLogBase <- function(playState, x.or.y=c("x", "y"))
 {
     x.or.y <- match.arg(x.or.y)
     if (playState$is.lattice) {
-        scalesArg <- callArg(playState, "scales")
-        if (!is.null(scalesArg[[x.or.y]]$log)) {
-            logBase <- latticeLogBase(scalesArg[[x.or.y]]$log)
-            if (!is.na(logBase)) return(logBase)
-        } else {
-            logBase <- latticeLogBase(scalesArg$log)
-            if (!is.na(logBase)) return(logBase)
-        }
+        scalesObj <- playState$trellis[[paste(x.or.y, "scales", sep=".")]]
+        x <- scalesObj$log
+        if (identical(x, FALSE)) return(NA)
+        if (isTRUE(x)) return(10)
+        if (identical(x, "e")) return(exp(1))
+        return(x)
     } else if (playState$is.ggplot) {
         logArg <- callArg(playState, "log")
         if (!is.null(logArg) &&
@@ -892,15 +894,6 @@ playLogBase <- function(playState, x.or.y=c("x", "y"))
     return(NA)
 }
 
-latticeLogBase <- function(x)
-{
-    x <- eval(x)
-    if (is.null(x) || identical(x, FALSE)) return(NA)
-    if (isTRUE(x)) return(10)
-    if (identical(x, "e")) return(exp(1))
-    x
-}
-
 whichSpace <- function(playState, x.device, y.device)
 {
     for (space in names(playState$deviceToSpace)) {
@@ -928,6 +921,7 @@ deviceCoordsToSpace <- function(playState, x.device, y.device, space = "plot")
     spaceFun(x.device, y.device)
 }
 
+
 ## this is called by playReplot
 ## makes a function to transform device native x, y (i.e. pixels)
 ## into plot coordinates (current viewport native coords if is.grid=T)
